@@ -1,6 +1,6 @@
 #--
 # =============================================================================
-# Copyright (c) 2004,2005 Jamis Buck (jamis_buck@byu.edu)
+# Copyright (c) 2004,2005 Jamis Buck (jamis@37signals.com)
 # All rights reserved.
 #
 # This source file is distributed as part of the Net::SSH Secure Shell Client
@@ -460,7 +460,7 @@ module Net
 
         # Invoked when the server sends a request packet. This in turn calls
         # the "on_request" callback.
-        event :request, :want_reply, :data
+        event :request, :type, :want_reply, :data
 
         # Invoked when the server sends confirmation of a successful operation.
         # This in turn invokes the "on_success" callback, if set.
