@@ -1,6 +1,6 @@
 #--
 # =============================================================================
-# Copyright (c) 2004,2005 Jamis Buck (jamis_buck@byu.edu)
+# Copyright (c) 2004,2005 Jamis Buck (jamis@37signals.com)
 # All rights reserved.
 #
 # This source file is distributed as part of the Net::SSH Secure Shell Client
@@ -14,7 +14,7 @@
 # =============================================================================
 #++
 
-$:.unshift "../../../lib"
+$:.unshift "#{File.dirname(__FILE__)}/../../../lib"
 
 require 'net/ssh/transport/ossl/digest-factory'
 require 'test/unit'
